# Optional Features: Tech Platform Fact Sheet (Meta Model v3)
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/tech-platform-fact-sheet-v3#overview)
  * [Step1: Install Tech Platforms](https://help.sap.com/docs/leanix/ea/tech-platform-fact-sheet-v3#step1:-install-tech-platforms)
  * [Step 2: Refresh Browser (and wait)](https://help.sap.com/docs/leanix/ea/tech-platform-fact-sheet-v3#step-2:-refresh-browser-\(and-wait\))
  * [Step 3: Define Tech Platforms](https://help.sap.com/docs/leanix/ea/tech-platform-fact-sheet-v3#step-3:-define-tech-platforms)
  * [Step 4: Connect Tech Platforms with Applications](https://help.sap.com/docs/leanix/ea/tech-platform-fact-sheet-v3#step-4:-connect-tech-platforms-with-applications)
  * [Step 5: Add IT Components to Applications](https://help.sap.com/docs/leanix/ea/tech-platform-fact-sheet-v3#step-5:-add-it-components-to-applications)


**Note**
  * This page is a modeling guideline for Meta Model v3. For updated guidelines for Meta Model v4 see [Meta Model v4](https://help.sap.com/docs/leanix/ea/meta-model?locale=en-US&state=PRODUCTION&version=CLOUD "Get an overview of the SAP LeanIX meta model and its key concepts.").
  * The Platform Fact Sheet in Meta Model V4 replaces the Tech Platform Fact Sheet from Meta Model V3. To learn more, see [Platform Modeling Guidelines](https://help.sap.com/docs/leanix/ea/platform-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to model platforms. This includes best practices and applicable use cases, and common antipatterns."). Use the Platform Fact Sheet to model your SAP BTP architecture. For best practices, see [Modeling SAP BTP](https://help.sap.com/docs/leanix/ea/modeling-sap-btp?locale=en-US&state=PRODUCTION&version=CLOUD "Learn best practices for SAP BTP modeling, including guidelines for gaining insights and general approaches to structure your SAP BTP architecture.").
